@@ -5,9 +5,12 @@ from rocketmq.client import PushConsumer, ConsumeStatus
 import json
 
 
-def rocketmq_handler_wrapper(f):
+def rocketmq_handler_wrapper(handlers):
     def message_handler(message):
-        ret = f(message)
+        f = handlers.get(message.tags.decode('utf-8'))
+        ret = False
+        if f !=None:
+            ret = f(message)
         if ret:
             return ConsumeStatus.CONSUME_SUCCESS
         else:
@@ -26,12 +29,20 @@ class ConsumerRocketMQ(ConsumerFactory):
         if access_key:
             self.consumer.set_session_credentials(
                 access_key=access_key, access_secret=access_secret, channel=channel)
+        self.__handlers=dict()
+        self.__topic_group=dict()
 
     def Register(self, topic_group: str, topic: str, callback, **route):
-        self.consumer.subscribe(
-            topic_group, rocketmq_handler_wrapper(callback), expression=topic)
+        self.__handlers[topic]=callback
+        if topic_group not in self.__topic_group:
+            self.__topic_group[topic_group]=[]
+        self.__topic_group[topic_group].append(topic)
+        
 
     def Start(self):
+        for topic_group, topics in self.__topic_group.items():
+            self.consumer.subscribe(
+            topic_group, rocketmq_handler_wrapper(self.__handlers), expression="||".join(topics))
         self.consumer.start()
 
     def Stop(self):
